==> ifhp-3.5.3.tgz: ifhp-3.5.3/src/errormsg.h <==
/**************************************************************************
 * LPRng IFHP Filter
 * Copyright 1994-1999 Patrick Powell, San Diego, CA <papowell@astart.com>
 **************************************************************************/
/**** HEADER *****
$Id: errormsg.h,v 1.4 2000/10/14 21:08:39 papowell Exp papowell $
 **** ENDHEADER ****/

#ifndef _ERRORMSG_H
#define _ERRORMSG_H

/* PROTOTYPES */
const char * Errormsg ( int err );
/* VARARGS2 */
#ifdef HAVE_STDARGS
void logmsg( char *msg,...)
#else
void logmsg(va_alist) va_dcl
#endif
 ;
/* VARARGS2 */
#ifdef HAVE_STDARGS
void logDebug( char *msg,...)
#else
void logDebug(va_alist) va_dcl
#endif
 ;
/* VARARGS2 */
#ifdef HAVE_STDARGS
void fatal ( char *msg,...)
#else
void fatal (va_alist) va_dcl
#endif
 ;
/* VARARGS2 */
#ifdef HAVE_STDARGS
void logerr (char *msg,...)
#else
void logerr (va_alist) va_dcl
#endif
 ;
/* VARARGS2 */
#ifdef HAVE_STDARGS
void logerr_die ( char *msg,...)
#else
void logerr_die (va_alist) va_dcl
#endif
 ;
char *Time_str(int shortform, time_t t);
int Write_fd_str( int fd, const char *str );
int Write_fd_len( int fd, const char *str, int len );
const char *Sigstr (int n);
void setstatus( char *msg, char *details, int trace );
int udp_open( char *device );

#if defined(FORMAT_TEST)
#define FATAL printf
#define LOGERR printf
#define LOGERR_DIE printf
#define LOGMSG printf
#define LOGDEBUG printf

#else
#define FATAL fatal
#define LOGERR logerr
#define LOGERR_DIE logerr_die
#define LOGMSG logmsg
#define LOGDEBUG logDebug
#endif


#endif

==> ifhp-3.5.5.tgz: ifhp-3.5.5/src/errormsg.h <==
/**************************************************************************
 * LPRng IFHP Filter
 * Copyright 1994-1999 Patrick Powell, San Diego, CA <papowell@astart.com>
 **************************************************************************/
/**** HEADER *****
$Id: errormsg.h,v 1.5 2002/01/30 14:34:18 papowell Exp papowell $
 **** ENDHEADER ****/

#ifndef _ERRORMSG_H
#define _ERRORMSG_H

#if defined(FORMAT_TEST)
#define LOGMSG(X) printf(
#define FATAL(X) printf(
#define LOGERR(X) printf(
#define LOGERR_DIE(X) printf(
#define LOGDEBUG printf
#define DIEMSG printf
#define WARNMSG printf
#define MESSAGE printf
#else
#define LOGMSG(X) logmsg(
#define FATAL(X) fatal(
#define LOGERR(X) logerr(
#define LOGERR_DIE(X) logerr_die(
#define LOGDEBUG logDebug
#define DIEMSG Diemsg
#define WARNMSG Warnmsg
#define MESSAGE Message
#endif

/* PROTOTYPES */
const char * Errormsg ( int err );
/* VARARGS2 */
#ifdef HAVE_STDARGS
void logmsg( char *msg,...)
#else
void logmsg(va_alist) va_dcl
#endif
 ;
/* VARARGS2 */
#ifdef HAVE_STDARGS
void logDebug( char *msg,...)
#else
void logDebug(va_alist) va_dcl
#endif
 ;
/* VARARGS2 */
#ifdef HAVE_STDARGS
void fatal ( char *msg,...)
#else
void fatal (va_alist) va_dcl
#endif
 ;
/* VARARGS2 */
#ifdef HAVE_STDARGS
void logerr (char *msg,...)
#else
void logerr (va_alist) va_dcl
#endif
 ;
/* VARARGS2 */
#ifdef HAVE_STDARGS
void logerr_die ( char *msg,...)
#else
void logerr_die (va_alist) va_dcl
#endif
 ;
char *Time_str(int shortform, time_t t);
int Write_fd_str( int fd, const char *str );
int Write_fd_len( int fd, const char *str, int len );
const char *Sigstr (int n);
void setstatus( char *msg, char *details, int trace );
int udp_open( char *device );

#endif
